@@ -15,7 +15,7 @@ package Term::RawInput;
 ## See user documentation at the end of this file.  Search for =head
 
 
-$VERSION = '1.22';
+$VERSION = '1.23';
 
 
 use 5.006;
@@ -43,7 +43,11 @@ sub rawInput {
    my $char='';
    my $output=$_[0];
    STDOUT->autoflush(1);
-   printf("\r% ${length_prompt}s",$output);
+   if (exists $ENV{PARdir} && $^O eq 'cygwin') {
+      printf("\r% ${length_prompt}s",$output."\n");
+   } else {
+      printf("\r% ${length_prompt}s",$output);
+   }
    STDOUT->autoflush(0);
    my $save='';
    while (1) {
